local mod = ...

--[[

	Adds vegetable gardens that produce vegetables, an early and cheap food.
	Gardens can be surrounded by a fence by default, or the woven fence	added as a decoration after the fields are created.

]]--


-- Job -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "VEGETABLEFARMER_JOB",
	JobName = "VEGETABLEFARMER_JOB_NAME",
	JobDescription = "VEGETABLEFARMER_JOB_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 70.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		RightHandObject = {
			DataType = "HAND_OBJECT",
			Model = "PREFAB_TOOL_COAL_BURNER_SHOVEL"
		},
		WalkAnimation = "WALKING",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "VEGETABLEFARMER_JOB"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "VEGETABLEFARMER_JOB"
    }
})



-- Resource -------------------------------------------------------------------------------------

mod:registerAssetId("icons/Vegetable.png", "ICON_VEGETABLE")

mod:register({
	DataType = "RESOURCE",
	Id = "VEGETABLE_RESOURCE",
	ResourceName = "VEGETABLE_RESOURCE_NAME",
	Icon = "ICON_VEGETABLE",
	ResourceTypeList = { "FOOD" },
	IsTradable = true,
	ResourceLayoutType = "CRATES",
	VillagerBuyingPrice = { Resource = "GOLD", Quantity = 2 },
	DisplayInInventory = true
})




-- Assets
mod:registerAssetId("models/VegetablePatch2.fbx/Prefab/ConstructionSteps/Step_0.001", "PREFAB_POST")

mod:registerAssetId("models/VegetablePatch2.fbx/Prefab/VegetablePatchPart", "PREFAB_VEGETABLEPATCH2")
mod:registerAssetId("models/VegetablePatch3.fbx/Prefab/VegetablePatchPart", "PREFAB_VEGETABLEPATCH3")
mod:registerAssetId("models/VegetablePatch4.fbx/Prefab/VegetablePatchPart", "PREFAB_VEGETABLEPATCH4")
mod:registerAssetId("models/VegetablePatch5.fbx/Prefab/VegetablePatchPart", "PREFAB_VEGETABLEPATCH5")
mod:registerAssetId("models/VegetablePatch6.fbx/Prefab/VegetablePatchPart", "PREFAB_VEGETABLEPATCH6")
mod:registerAssetId("models/VegetablePatch7.fbx/Prefab/VegetablePatchPart", "PREFAB_VEGETABLEPATCH7")
mod:registerAssetId("models/VegetablePatch8.fbx/Prefab/VegetablePatchPart", "PREFAB_VEGETABLEPATCH8")
mod:registerAssetId("models/VegetablePatch9.fbx/Prefab/VegetablePatchPart", "PREFAB_VEGETABLEPATCH9")

mod:registerAssetId("models/VegetablePatch2n.fbx/Prefab/VegetablePatchPart", "PREFAB_VEGETABLEPATCH2N")
mod:registerAssetId("models/VegetablePatch3n.fbx/Prefab/VegetablePatchPart", "PREFAB_VEGETABLEPATCH3N")
mod:registerAssetId("models/VegetablePatch4n.fbx/Prefab/VegetablePatchPart", "PREFAB_VEGETABLEPATCH4N")
mod:registerAssetId("models/VegetablePatch5n.fbx/Prefab/VegetablePatchPart", "PREFAB_VEGETABLEPATCH5N")
mod:registerAssetId("models/VegetablePatch6n.fbx/Prefab/VegetablePatchPart", "PREFAB_VEGETABLEPATCH6N")
mod:registerAssetId("models/VegetablePatch7n.fbx/Prefab/VegetablePatchPart", "PREFAB_VEGETABLEPATCH7N")
mod:registerAssetId("models/VegetablePatch8n.fbx/Prefab/VegetablePatchPart", "PREFAB_VEGETABLEPATCH8N")
mod:registerAssetId("models/VegetablePatch9n.fbx/Prefab/VegetablePatchPart", "PREFAB_VEGETABLEPATCH9N")



-- Building Asset Processor
mod:registerAssetProcessor("models/VegetablePatch2.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/VegetablePatch3.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/VegetablePatch4.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/VegetablePatch5.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/VegetablePatch6.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/VegetablePatch7.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/VegetablePatch8.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/VegetablePatch9.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })

mod:registerAssetProcessor("models/VegetablePatch2n.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/VegetablePatch3n.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/VegetablePatch4n.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/VegetablePatch5n.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/VegetablePatch6n.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/VegetablePatch7n.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/VegetablePatch8n.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/VegetablePatch9n.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })



-- Construction visual
mod:registerAssetId("models/VegetablePatch2.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_VEGETABLEPATCH2")
mod:registerAssetId("models/VegetablePatch3.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_VEGETABLEPATCH3")
mod:registerAssetId("models/VegetablePatch4.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_VEGETABLEPATCH4")
mod:registerAssetId("models/VegetablePatch5.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_VEGETABLEPATCH5")
mod:registerAssetId("models/VegetablePatch6.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_VEGETABLEPATCH6")
mod:registerAssetId("models/VegetablePatch7.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_VEGETABLEPATCH7")
mod:registerAssetId("models/VegetablePatch8.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_VEGETABLEPATCH8")
mod:registerAssetId("models/VegetablePatch9.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_VEGETABLEPATCH9")

mod:registerAssetId("models/VegetablePatch2n.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_VEGETABLEPATCH2N")
mod:registerAssetId("models/VegetablePatch3n.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_VEGETABLEPATCH3N")
mod:registerAssetId("models/VegetablePatch4n.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_VEGETABLEPATCH4N")
mod:registerAssetId("models/VegetablePatch5n.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_VEGETABLEPATCH5N")
mod:registerAssetId("models/VegetablePatch6n.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_VEGETABLEPATCH6N")
mod:registerAssetId("models/VegetablePatch7n.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_VEGETABLEPATCH7N")
mod:registerAssetId("models/VegetablePatch8n.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_VEGETABLEPATCH8N")
mod:registerAssetId("models/VegetablePatch9n.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_VEGETABLEPATCH9N")



-- Dirt rectangle
-- mod:registerPrefabComponent("models/VegetablePatch2.fbx/Prefab/VegetablePatchPart", { DataType = "COMP_DIRT_RECTANGLE",	Size = {9.0, 9.0} })
-- mod:registerPrefabComponent("models/VegetablePatch3.fbx/Prefab/VegetablePatchPart", { DataType = "COMP_DIRT_RECTANGLE",	Size = {8.75, 8.75} })
-- mod:registerPrefabComponent("models/VegetablePatch4.fbx/Prefab/VegetablePatchPart", { DataType = "COMP_DIRT_RECTANGLE",	Size = {9.0, 9.0} })
-- mod:registerPrefabComponent("models/VegetablePatch5.fbx/Prefab/VegetablePatchPart", { DataType = "COMP_DIRT_RECTANGLE",	Size = {8.75, 8.75} })
-- mod:registerPrefabComponent("models/VegetablePatch6.fbx/Prefab/VegetablePatchPart", { DataType = "COMP_DIRT_RECTANGLE",	Size = {9.0, 9.0} })
-- mod:registerPrefabComponent("models/VegetablePatch7.fbx/Prefab/VegetablePatchPart", { DataType = "COMP_DIRT_RECTANGLE",	Size = {8.75, 8.75} })

-- mod:registerPrefabComponent("models/VegetablePatch2n.fbx/Prefab/VegetablePatchPart", { DataType = "COMP_DIRT_RECTANGLE", Size = {5.0, 9.0} })
-- mod:registerPrefabComponent("models/VegetablePatch3n.fbx/Prefab/VegetablePatchPart", { DataType = "COMP_DIRT_RECTANGLE", Size = {5.0, 9.0} })
-- mod:registerPrefabComponent("models/VegetablePatch4n.fbx/Prefab/VegetablePatchPart", { DataType = "COMP_DIRT_RECTANGLE", Size = {5.0, 9.0} })
-- mod:registerPrefabComponent("models/VegetablePatch5n.fbx/Prefab/VegetablePatchPart", { DataType = "COMP_DIRT_RECTANGLE", Size = {5.0, 9.0} })
-- mod:registerPrefabComponent("models/VegetablePatch6n.fbx/Prefab/VegetablePatchPart", { DataType = "COMP_DIRT_RECTANGLE", Size = {5.0, 9.0} })
-- mod:registerPrefabComponent("models/VegetablePatch7n.fbx/Prefab/VegetablePatchPart", { DataType = "COMP_DIRT_RECTANGLE", Size = {5.0, 9.0} })



-- Grounding construction visuals
for i=1, 20, 1 do
	mod:registerPrefabComponent("models/VegetablePatch2.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch2.fbx/Prefab/ConstructionSteps/Step_1." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch3.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch4.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch4.fbx/Prefab/ConstructionSteps/Step_1." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch5.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch6.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch6.fbx/Prefab/ConstructionSteps/Step_1." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch7.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch8.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch8.fbx/Prefab/ConstructionSteps/Step_1." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch9.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})

	mod:registerPrefabComponent("models/VegetablePatch2n.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch2n.fbx/Prefab/ConstructionSteps/Step_1." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch3n.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch4n.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch4n.fbx/Prefab/ConstructionSteps/Step_1." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch5n.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch6n.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch6n.fbx/Prefab/ConstructionSteps/Step_1." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch7n.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch8n.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch8n.fbx/Prefab/ConstructionSteps/Step_1." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch9n.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
end


-- Grounding fences
for i=1, 20, 1 do
	mod:registerPrefabComponent("models/VegetablePatch2.fbx/Prefab/VegetablePatchPart/Fence." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch4.fbx/Prefab/VegetablePatchPart/Fence." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch6.fbx/Prefab/VegetablePatchPart/Fence." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch8.fbx/Prefab/VegetablePatchPart/Fence." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})

	mod:registerPrefabComponent("models/VegetablePatch2n.fbx/Prefab/VegetablePatchPart/Fence." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch4n.fbx/Prefab/VegetablePatchPart/Fence." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch6n.fbx/Prefab/VegetablePatchPart/Fence." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch8n.fbx/Prefab/VegetablePatchPart/Fence." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
end


-- Grounding plants
for i=1, 60, 1 do
	mod:registerPrefabComponent("models/VegetablePatch2.fbx/Prefab/VegetablePatchPart/Plant." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch3.fbx/Prefab/VegetablePatchPart/Plant." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch4.fbx/Prefab/VegetablePatchPart/Plant." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch5.fbx/Prefab/VegetablePatchPart/Plant." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch6.fbx/Prefab/VegetablePatchPart/Plant." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch8.fbx/Prefab/VegetablePatchPart/Plant." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch9.fbx/Prefab/VegetablePatchPart/Plant." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})

	mod:registerPrefabComponent("models/VegetablePatch2n.fbx/Prefab/VegetablePatchPart/Plant." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch3n.fbx/Prefab/VegetablePatchPart/Plant." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch4n.fbx/Prefab/VegetablePatchPart/Plant." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch5n.fbx/Prefab/VegetablePatchPart/Plant." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch6n.fbx/Prefab/VegetablePatchPart/Plant." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch8n.fbx/Prefab/VegetablePatchPart/Plant." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/VegetablePatch9n.fbx/Prefab/VegetablePatchPart/Plant." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
end



-- Building Function: Vegetable field -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "VEGETABLEPATCH_FUNCTION",
    Name = "VEGETABLEPATCH_FUNCTION_NAME",
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "VEGETABLEFARMER_JOB", 
        Behavior = "BEHAVIOR_WORK"
    },
    InputInventoryCapacity = {
		{ Resource = "WATER", Quantity = 5 },
		{ Resource = "DUNG_RESOURCE", Quantity = 5 }
	},
    ResourceListNeeded = {
		{ Resource = "WATER", Quantity = 1 },
		{ Resource = "DUNG_RESOURCE", Quantity = 1 },
	},
	ResourceProduced = {{ Resource = "VEGETABLE_RESOURCE", Quantity = 1 }}

})


-- Building -------------------------------------------------------------------------------------

mod:register({
	DataType = "BUILDING", 
	Id = "VEGETABLEFARM",
	Name = "VEGETABLEFARM_NAME",
	Description = "VEGETABLEFARM_DESC",
	BuildingType = "GENERAL",
	AssetCoreBuildingPart = "POST_PART",
	BuildingPartSetList = {
		{
			Name = "VEGETABLEPATCH_SET1_NAME",
			BuildingPartList = { 
				"VEGETABLEPATCH2_PART",
				"VEGETABLEPATCH4_PART",
				"VEGETABLEPATCH8_PART",
				"VEGETABLEPATCH6_PART",
			}
		},
		{
			Name = "VEGETABLEPATCH_SET2_NAME",
			BuildingPartList = { 
				"VEGETABLEPATCH2N_PART",
				"VEGETABLEPATCH4N_PART",
				"VEGETABLEPATCH8N_PART",
				"VEGETABLEPATCH6N_PART",
			}
		},
		{
			Name = "VEGETABLEPATCH_SET3_NAME",
				BuildingPartList = { 
					"VEGETABLEPATCH3_PART",
					"VEGETABLEPATCH5_PART",
					"VEGETABLEPATCH9_PART",
					"VEGETABLEPATCH7_PART",
				}
		},
		{
			Name = "VEGETABLEPATCH_SET4_NAME",
			BuildingPartList = { 
				"VEGETABLEPATCH3N_PART",
				"VEGETABLEPATCH5N_PART",
				"VEGETABLEPATCH9N_PART",
				"VEGETABLEPATCH7N_PART",
			}
		},
	},	
	RequiredPartList = {
		{ Category = "CORE", Quantity = 1 }
	},
	IsEditable = true
})


-- Building Part: Post -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "POST_PART",
	Name = "POST_PART_NAME", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_POST"
	},
	IsVisibleWhenBuilt = false
})



-- Building Part: Vegetable Patch 2 (beet field with fence) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "VEGETABLEPATCH2_PART",
	Name = "VEGETABLEPATCH2_PART_NAME", 
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_VEGETABLEPATCH2"
	},
	ConstructionVisual = "PREFAB_CONSTR_VEGETABLEPATCH2",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {9.6, 9.6}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "VEGETABLEPATCH_FUNCTION",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 5 },
            { Resource = "TOOL", Quantity = 1 }
		}
	}
})



-- Building Part: Vegetable Patch 2n (narrow beet field with fence) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "VEGETABLEPATCH2N_PART",
	Name = "VEGETABLEPATCH2N_PART_NAME", 
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_VEGETABLEPATCH2N"
	},
	ConstructionVisual = "PREFAB_CONSTR_VEGETABLEPATCH2N",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {6.5, 9.6}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "VEGETABLEPATCH_FUNCTION",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 4 },
            { Resource = "TOOL", Quantity = 1 }
		}
	}
})


-- Building Part: Vegetable Patch 3 (beet field) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "VEGETABLEPATCH3_PART",
	Name = "VEGETABLEPATCH3_PART_NAME", 
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_VEGETABLEPATCH3"
	},
	ConstructionVisual = "PREFAB_CONSTR_VEGETABLEPATCH3",
	AssetBuildingFunction = "VEGETABLEPATCH_FUNCTION",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {7.0, 7.0}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 2 },
            { Resource = "TOOL", Quantity = 1 }
		}
	}
})



-- Building Part: Vegetable Patch 3n (narrow beet field) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "VEGETABLEPATCH3N_PART",
	Name = "VEGETABLEPATCH3N_PART_NAME", 
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_VEGETABLEPATCH3N"
	},
	ConstructionVisual = "PREFAB_CONSTR_VEGETABLEPATCH3N",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {4.0, 7.0}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "VEGETABLEPATCH_FUNCTION",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 4 },
            { Resource = "TOOL", Quantity = 1 }
		}
	}
})


-- Building Part: Vegetable Patch 4 (cabbage field with fence) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "VEGETABLEPATCH4_PART",
	Name = "VEGETABLEPATCH4_PART_NAME", 
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_VEGETABLEPATCH4"
	},
	ConstructionVisual = "PREFAB_CONSTR_VEGETABLEPATCH4",
	AssetBuildingFunction = "VEGETABLEPATCH_FUNCTION",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {9.6, 9.6}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 5 },
            { Resource = "TOOL", Quantity = 1 }
		}
	}
})



-- Building Part: Vegetable Patch 4n (narrow cabbage field with fence) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "VEGETABLEPATCH4N_PART",
	Name = "VEGETABLEPATCH4N_PART_NAME", 
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_VEGETABLEPATCH4N"
	},
	ConstructionVisual = "PREFAB_CONSTR_VEGETABLEPATCH4N",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {6.5, 9.6}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "VEGETABLEPATCH_FUNCTION",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 4 },
            { Resource = "TOOL", Quantity = 1 }
		}
	}
})



-- Building Part: Vegetable Patch 5 (cabbage field) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "VEGETABLEPATCH5_PART",
	Name = "VEGETABLEPATCH5_PART_NAME", 
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_VEGETABLEPATCH5"
	},
	ConstructionVisual = "PREFAB_CONSTR_VEGETABLEPATCH5",
	AssetBuildingFunction = "VEGETABLEPATCH_FUNCTION",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {7.0, 7.0}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 2 },
            { Resource = "TOOL", Quantity = 1 }
		}
	}
})



-- Building Part: Vegetable Patch 5n (narrow cabbage field) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "VEGETABLEPATCH5N_PART",
	Name = "VEGETABLEPATCH5N_PART_NAME", 
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_VEGETABLEPATCH5N"
	},
	ConstructionVisual = "PREFAB_CONSTR_VEGETABLEPATCH5N",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {4.0, 7.0}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "VEGETABLEPATCH_FUNCTION",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 4 },
            { Resource = "TOOL", Quantity = 1 }
		}
	}
})



-- Building Part: Vegetable Patch 6 (fallow field with fence) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "VEGETABLEPATCH6_PART",
	Name = "VEGETABLEPATCH6_PART_NAME", 
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_VEGETABLEPATCH6"
	},
	ConstructionVisual = "PREFAB_CONSTR_VEGETABLEPATCH6",
	AssetBuildingFunction = "VEGETABLEPATCH_FUNCTION",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {9.6, 9.6}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 5 },
            { Resource = "TOOL", Quantity = 1 }
		}
	}
})



-- Building Part: Vegetable Patch 6n (narrow fallow field with fence) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "VEGETABLEPATCH6N_PART",
	Name = "VEGETABLEPATCH6N_PART_NAME", 
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_VEGETABLEPATCH6N"
	},
	ConstructionVisual = "PREFAB_CONSTR_VEGETABLEPATCH6N",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {6.5, 9.6}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "VEGETABLEPATCH_FUNCTION",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 4 },
            { Resource = "TOOL", Quantity = 1 }
		}
	}
})



-- Building Part: Vegetable Patch 7 (fallow field) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "VEGETABLEPATCH7_PART",
	Name = "VEGETABLEPATCH7_PART_NAME", 
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_VEGETABLEPATCH7"
	},
	ConstructionVisual = "PREFAB_CONSTR_VEGETABLEPATCH7",
	AssetBuildingFunction = "VEGETABLEPATCH_FUNCTION",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {7.0, 7.0}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 2 },
            { Resource = "TOOL", Quantity = 1 }
		}
	}
})



-- Building Part: Vegetable Patch 7n (narrow fallow field) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "VEGETABLEPATCH7N_PART",
	Name = "VEGETABLEPATCH7N_PART_NAME", 
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_VEGETABLEPATCH7N"
	},
	ConstructionVisual = "PREFAB_CONSTR_VEGETABLEPATCH7N",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {4.0, 7.0}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "VEGETABLEPATCH_FUNCTION",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 4 },
            { Resource = "TOOL", Quantity = 1 }
		}
	}
})



-- Building Part: Vegetable Patch 8 (bean field with fence) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "VEGETABLEPATCH8_PART",
	Name = "VEGETABLEPATCH8_PART_NAME", 
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_VEGETABLEPATCH8"
	},
	ConstructionVisual = "PREFAB_CONSTR_VEGETABLEPATCH8",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {9.6, 9.6}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "VEGETABLEPATCH_FUNCTION",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 5 },
            { Resource = "TOOL", Quantity = 1 }
		}
	}
})



-- Building Part: Vegetable Patch 8n (narrow bean field with fence) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "VEGETABLEPATCH8N_PART",
	Name = "VEGETABLEPATCH8N_PART_NAME", 
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_VEGETABLEPATCH8N"
	},
	ConstructionVisual = "PREFAB_CONSTR_VEGETABLEPATCH8N",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {6.5, 9.6}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "VEGETABLEPATCH_FUNCTION",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 4 },
            { Resource = "TOOL", Quantity = 1 }
		}
	}
})



-- Building Part: Vegetable Patch 9 (bean field) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "VEGETABLEPATCH9_PART",
	Name = "VEGETABLEPATCH9_PART_NAME", 
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_VEGETABLEPATCH9"
	},
	ConstructionVisual = "PREFAB_CONSTR_VEGETABLEPATCH9",
	AssetBuildingFunction = "VEGETABLEPATCH_FUNCTION",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {7.0, 7.0}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 2 },
            { Resource = "TOOL", Quantity = 1 }
		}
	}
})



-- Building Part: Vegetable Patch 9n (narrow bean field) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "VEGETABLEPATCH9N_PART",
	Name = "VEGETABLEPATCH9N_PART_NAME", 
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_VEGETABLEPATCH9N"
	},
	ConstructionVisual = "PREFAB_CONSTR_VEGETABLEPATCH9N",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {4.0, 7.0}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "VEGETABLEPATCH_FUNCTION",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 4 },
            { Resource = "TOOL", Quantity = 1 }
		}
	}
})
